@@ -44,6 +44,19 @@ class ConfigObject(object):
         **kwargs: Keyword arguments of property values to set upon construction.
 
         """
+
+        # We don't want the section to introduce subsections, so translate . to
+        # -.  Since underscore is not allowed in a config key, translate them to -
+        # as well.
+
+        tr_table = project_section.maketrans('._', '--')
+        project_section = project_section.translate(tr_table)
+
+        # Also with pygit2 the key can't start with - so prepend a legal string.
+
+        if project_section.startswith('-'):
+            project_section = 'ZZ' + project_section
+
         self._git = git
         self._project_section = project_section
         self._subsection = subsection
@@ -142,7 +155,8 @@ class ConfigObject(object):
                                                     subsection,
                                                     ident)
 
-        return True if git.config.get_section(gitsection) else False
+        section = git.config.get_section(gitsection)
+        return True if section else False
 
     @staticmethod
     def _get_full_section(section, subsection, ident):
@@ -209,6 +223,10 @@ class ConfigObject(object):
         """Return the section of this object."""
         return self._section
 
+    def get_subsection(self):
+        """Return the subsection of this object."""
+        return self._subsection
+
     def _set_item(self, name, value):
         """Set property name to value and write it to the git config."""
         if not hasattr(self.__class__, name):
