@@ -83,21 +83,53 @@ class SubstitutableConfigObject(ConfigObject):
             path = git.get_working_copy_root()
             formats['path'] = path
 
-        formats['branch'] = git.get_current_branch()
+        current_branch = git.get_current_branch()
+        if not current_branch:
+            # See if we're rebasing and use the branch being rebased for the substitution.
+            worktree = git.get_current_worktree()
+            common_dir = git.get_git_common_dir()
+
+            if worktree:
+                common_dir = f'{common_dir}/worktrees/{worktree}'
+
+            rebase_apply = f'{common_dir}/rebase-apply'
+            rebase_merge = f'{common_dir}/rebase-merge'
+
+            for rebase_path in (rebase_apply, rebase_merge):
+                head_name = Path(f'{rebase_path}/head-name')
+                if head_name.exists():
+                    current_branch = git.refname_to_branch_name(head_name.read_text().strip())
+                    break
+
+        formats['branch'] = current_branch
+
+        def try_format(string, formats):
+            return eval(f"f'{string}'", formats)
+
+        def add_scope(project, key, formats):
+            print(f'Trying scope key: {key}')
+            scope = project.get_scope(key)
+            if scope:
+                value = scope.get_ident()
+                formats[key] = value
 
         while True:
             try:
-                newstring = string.format(**formats)
+                newstring = try_format(string, formats)
             except KeyError as exception:
                 # See if this is a scope name.
                 for key in exception.args:
-                    scope = project.get_scope(key)
-                    if scope:
-                        value = scope.get_ident()
-                        formats[key] = value
-
+                    add_scope(project, key, formats)
                 # Try again after adding scopes.
-                newstring = string.format(**formats)
+                newstring = try_format(string, formats)
+            except NameError as exception:
+                # args is simply the error  message, with the name surrounded by
+                # '.  Use .name attribute after upgrading to python 3.10.
+                for arg in exception.args:
+                    key = arg.split("\'")[1]
+                    add_scope(project, key, formats)
+                # Try again after adding scopes.
+                newstring = try_format(string, formats)
 
             changed = False if newstring == string else True
             string = newstring
